package
Version:
v1.2.1
Opens a new window with list of versions in this module.
Published: Apr 7, 2023
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package openapi openApi管理
ClearQuotaV2 使用AppSecret重置API调用次数
type Quota struct {
DailyLimit int64 `json:"daily_limit,omitempty"`
Used int64 `json:"used,omitempty"`
Remain int64 `json:"remain,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.