package
Version:
v1.1.10
Opens a new window with list of versions in this module.
Published: Mar 14, 2023
License: Apache-2.0
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func AuthCodeURL(appId, redirectURI, scope, state string) string
type UserInfo struct {
UserId string `json:"UserId"`
OpenId string `json:"OpenId"`
}
GetUserInfo 获取用户信息.
accessToken: 网页授权接口调用凭证
code: 通过成员授权获取到的code,最大为512字节。每次成员授权带上的code将不一样,code只能使用一次,5分钟未被使用自动过期。
httpClient: 如果不指定则默认为 util.DefaultHttpClient
Source Files
¶
Click to show internal directories.
Click to hide internal directories.